@@ -12,9 +12,9 @@ if [ "$clean" = 1 ]; then
 fi
 
 run_and_exit "make -C .."
-../obj/test_htables
-../obj/test_arrays
-../obj/test_strings
-../obj/test_trie
+$valgrind ../obj/test_htables
+$valgrind ../obj/test_arrays
+$valgrind ../obj/test_strings
+$valgrind ../obj/test_trie
 
 echo_with_status 1 ""
