@@ -3,7 +3,7 @@
 #include <errno.h>
 #include <string.h>
 #include <config.h>
-#include <db.h>
+#include <db_185.h>
 #include <sn.h>
 
 /* RESTRICTED_CURSOR is used to check if all cursors were released after use */
