@@ -1,20 +1,26 @@
-## This package provides support for:
-##  - storing the documentation for any Python entity in a separate XML file.
-##    This allows dynamia modification (post it for instance), easier
-##    translation, and saves some memory since it doesn't need to be kept
-##    in memory at all times, and once per language in addition.
-##
-##  - Dynamically generating HTML file to document python entities. In
-##    particular, a predefined menu is added for the GPS extensions
+"""Enhanced documentation for python and GPS shell commands
 
-import GPS, pydoc, os, inspect, pydoc, sys, re
+This package provides support for:
+ - storing the documentation for any Python entity in a separate XML file.
+   This allows dynamic modification, easier
+   translation, and saves some memory since it doesn't need to be kept
+   in memory at all times, and once per language in addition.
+
+ - Dynamically generating HTML file to document python entities. In
+   particular, a predefined menu is added for the GPS extensions
+"""
+
+
+############################################################################
+## No user customization below this line
+############################################################################
+
+import GPS, pydoc, os, inspect, pydoc, sys, re, shutil
 from string import rstrip, lstrip, expandtabs
 
-#####################################################################
-##  The following classes provide a nice way to display HTML documentation.
-##  They are mostly useful for the GPS module, although they are expected to
-##  work on other modules as well
-#####################################################################
+# The following classes provide a nice way to display HTML documentation.
+# They are mostly useful for the GPS module, although they are expected to
+# work on other modules as well
 
 class DocGenerator:
    def __init__ (self):
@@ -62,6 +68,9 @@ class DocGenerator:
       """Replace all links like module_name.<...> by hyperlinks"""
 
       pattern = re.compile (module_name + r'\.(\w+)(\.(\w+))?')
+      m = __import__ (module_name)
+      routines = inspect.getmembers (m, inspect.isroutine)
+
       here = 0
       result = []
       linked_module = "<a href='file://" + self.filename_for_module (module_name) + "'>" + module_name + "</a>."
@@ -73,9 +82,17 @@ class DocGenerator:
          result.append (text[here:start])
 
          name1, foo, name2 = match.groups()
-         if foo:
+
+         is_routine = False
+         for r in routines:
+            if name1 == r[0]:
+               is_routine = True
+
+         if name2:
             result.append (linked_module + "<a href='file://" + self.filename_for_class (name1) + "'>" + name1 \
               + "</a>.<a href='file://" + self.filename_for_class (name1) + "#" + self.anchor_name (name2) + "'>" + name2 + "</a>")
+         elif is_routine:
+            result.append (linked_module + "<a href='file://" + self.filename_for_global (module_name) + "#" + self.anchor_name (name1) + "'>" + name1 + "</a>")
          else:
             result.append (linked_module + "<a href='file://" + self.filename_for_class (name1) + "'>" + name1 + "</a>")
 
@@ -90,13 +107,9 @@ class DocGenerator:
 
    def get_formated_documentation (self, module_name, object):
       """Same as get_documentation, except new lines that should be protected
-         are also protected in the output of get_formated_documentation"""
+         are also protected in the output of get_formated_documentation.
+         < or > symbols are expected to be already protected at this point."""
       doc = self.get_documentation (object) or ""
-      doc = "&amp;".join (doc.split ('&'))
-      doc = "&lt; ".join (doc.split ('< '))
-      doc = "&lt;,".join (doc.split ('<, '))
-      doc = "&gt; ".join (doc.split ('> '))
-      doc = "&gt;,".join (doc.split ('>,'))
       doc = "<p>\n".join (doc.split ("\n\n"))
 
       return self.setup_links (module_name, doc)
@@ -125,11 +138,33 @@ class DocGenerator:
 
       if inspect.isclass (object):
         mro     = inspect.getmro (object)
-        if len (mro) > 1:
+
+        children=[]
+        for (name, g) in inspect.getmembers (GPS, inspect.isclass):
+          if g != object and object in inspect.getmro(g):
+             children.append (g)
+
+        if len (mro) > 1 or len (children) > 0:
            output += "<tr><td colspan='3' class='title'>Inheritance tree</td></tr>" \
-              + "<tr><td colspan='3'><ul>\n"
-           for base in mro:
-               output += "  <li>" + self.full_name (base) + "</li>\n"
+              + "<tr><td colspan='3'><ul class='inheritance'>\n"
+
+           parents = [m for m in mro]
+           parents.reverse()
+           prefix=""
+           for base in parents[:-1]:
+             output += "  <li>" + prefix
+             output += "<img src='childtree.png' alt='_'/>"
+             output += self.full_name (base) + "</li>\n"
+             prefix += "<img src='childtree2.png' alt='  '/>"
+
+           output += "  <li>" + prefix + "<img src='childtree.png' alt='_'/>" \
+             + "<b>" + self.full_name (object) + "</b></li>\n"
+           prefix += "<img src='childtree2.png' alt='  '/>" + \
+             "<img src='childtree.png' alt='_'/>"
+
+           for c in sorted (children):
+            output += "  <li>" + prefix + self.full_name (c) + "</li>\n"
+
            output += "</ul></td></tr>"
 
       output += "</table>\n"
@@ -201,6 +236,8 @@ div.menu ul       { color: #369;
                     margin: 3px 0px 0px 20px;
                     padding: 0px }
 div.menu li       { margin-top: 3px; }
+ul.inheritance    { margin: 0; padding-left: 5px }
+ul.inheritance li { list-style-type: none; }
 div.documentation { position: relative;
                     top: 8px;
                     margin-left: 210px;
@@ -544,6 +581,11 @@ def generate_doc (entity):
   ## Generate the documentation for our own module
   name = docgen.html_documentation (entity)
 
+  shutil.copy (GPS.get_system_dir() + "share/gps/plug-ins/childtree.png",
+               GPS.get_home_dir() + "generated_doc")
+  shutil.copy (GPS.get_system_dir() + "share/gps/plug-ins/childtree2.png",
+               GPS.get_home_dir() + "generated_doc")
+
   ## These comment lines are for use through pydoc
   #home_dir = GPS.get_home_dir()
   #name = home_dir + os.sep + entity.__name__ + ".html"
@@ -559,15 +601,16 @@ def generate_doc (entity):
 def browse_doc (entity):
   """Open a browser for the documentation relative to the specified entity"""
   ## Use a hook, so that users can substitute their internal browser if they wish
-  GPS.Hook ("html_action_hook").run (GPS.File (generate_doc (entity)), 1, "")
+  GPS.Hook ("html_action_hook").run (generate_doc (entity), 1, "")
 
-## Create a default menu for the python documentation
-GPS.parse_xml("""
+def on_gps_started (hook_name):
+  """Creates the menus for this package"""
+  GPS.parse_xml("""
   <documentation_file>
        <shell lang="python">python_doc.browse_doc(GPS)</shell>
        <descr>GPS'extensions for Python</descr>
        <menu before="About">/Help/Python extensions</menu>
        <category>Scripts</category>
-    </documentation_file>""")
-
+  </documentation_file>""")
 
+GPS.Hook ("gps_started").add (on_gps_started)
