@@ -1,34 +1,45 @@
+"""This file provides enhanced support for editing Python files
 
-## Nothing is done if the projects do not support python, otherwise, the
-## following are provided:
-##   - Create highlight rules for python files
-##   - Defines a convenient filter "Python File" to use when defining your
-##     own actions
-##   - New menu to reload the current script. This menu is only visible when
-##     editing a python file.
-##   - Easy access to standard python library through shift-F3
-##   - Easy access to user-defined GPS configuration scripts through shift-F3
-##     This is always active, even if the current project doesn't support
-##     python
-##   - Add links to python documentation on the internet
+Nothing is done if the projects do not support python, otherwise, the
+following are provided:
+  - Create highlight rules for python files
+  - Defines a convenient filter "Python File" to use when defining your
+    own actions
+  - New menu to reload the current script. This menu is only visible when
+    editing a python file.
+  - Easy access to standard python library through shift-F3
+  - Easy access to user-defined GPS configuration scripts through shift-F3
+    This is always active, even if the current project doesn't support
+    python
+  - Add links to python documentation on the internet
+"""
 
-## To be added (from idle environment)
-##   - "indent region", "dedent region", "check module", "run module"
-##   - "class browser" -> project view in GPS
+
+############################################################################
+## No user customization below this line
+############################################################################
+
+# To be added (from idle environment)
+#   - "indent region", "dedent region", "check module", "run module"
+#   - "class browser" -> project view in GPS
 
 import GPS, sys, os.path
 
+GPS.Preference ("Plugins/python_support/port").create (
+   "Pydoc port", "integer", """Port that should be used when spawning the pydoc daemon.
+This is a small local server to which your web browser connects to display the documentation for the standard python library. It is accessed through the /Python menu when editing a python file""", 9432)
+
+try:
+  import gtk
+  has_pygtk=1
+except:
+  has_pygtk=0
 
 pydoc_proc = None
-pydoc_port = 9432
 python_menu = None
 
-def create_python_menu():
-  global python_menu
-  if not python_menu:
-     python_menu = GPS.Menu.create ("/Python", ref="Help", add_before=1)
-     GPS.Menu.create ("/Python/Import & Reload", on_activate=reload_file)
-     GPS.parse_xml ("""
+def register_doc():
+  GPS.parse_xml ("""
   <documentation_file>
      <name>http://www.python.org/doc/2.4.2/tut/tut.html</name>
      <descr>Python tutorial</descr>
@@ -42,6 +53,28 @@ def create_python_menu():
      <category>Scripts</category>
   </documentation_file>""")
 
+  if has_pygtk:
+        GPS.parse_xml ("""
+  <documentation_file>
+     <name>http://www.pygtk.org/pygtk2tutorial/index.html</name>
+     <descr>PyGTK tutorial</descr>
+     <menu>/Python/PyGTK Tutorial</menu>
+     <category>Scripts</category>
+  </documentation_file>
+  <documentation_file>
+     <name>http://www.pygtk.org/pygtk2reference/index.html</name>
+     <descr>PyGTK Reference Manual</descr>
+     <menu>/Python/PyGTK Reference Manual</menu>
+     <category>Scripts</category>
+  </documentation_file>""")
+
+def create_python_menu():
+  global python_menu
+  if not python_menu:
+     python_menu = GPS.Menu.create ("/Python", ref="Help", add_before=1)
+     GPS.Menu.create ("/Python/Import & Reload", on_activate=reload_file)
+     register_doc ()
+
 def destroy_python_menu():
   global python_menu
   if python_menu:
@@ -79,7 +112,7 @@ Otherwise, reload the current version of the file."""
 
         ## The proper solution is to execute in the context of the GPS console
         GPS.exec_in_console ("import " + module)
-        
+
   except:
      pass   ## Current context is not a file
 
@@ -107,7 +140,10 @@ def project_recomputed (hook_name):
 
 def show_python_library ():
   """Open a navigator to show the help on the python library"""
-  global pydoc_proc, pydoc_port
+  global pydoc_proc
+
+  pydoc_port = GPS.Preference ("Plugins/python_support/port").get()
+
   if not pydoc_proc:
      while 1:
         pydoc_proc = GPS.Process ("pydoc -p " + `pydoc_port`)
@@ -127,13 +163,10 @@ def before_exit (hook_name):
     pydoc_proc = None
   return 1
 
-
-### Do not call create_python_menu yet, since keeping a hidden toplevel menu
-### triggers bugs in gtk+, for instance leaving an empty space in the menubar
-
-GPS.Hook ("project_view_changed").add (project_recomputed)
-GPS.Hook ("before_exit_action_hook").add (before_exit)
-GPS.Hook ("context_changed").add (context_changed)
+## Always register python immediately as a language, so that projects that
+## have
+##    for Languages use ("Python");
+## do not have to define a naming scheme and can depend on the default.
 
 GPS.parse_xml ("""
   <Language>
@@ -170,3 +203,6 @@ GPS.parse_xml ("""
   </filter_and>
 """)
 
+GPS.Hook ("project_view_changed").add (project_recomputed)
+GPS.Hook ("before_exit_action_hook").add (before_exit)
+GPS.Hook ("context_changed").add (context_changed)
