@@ -1,33 +1,41 @@
-### Support file for the GNAT Programm System
-##
-## This file provides two sort functions, which can be used to sort lines
-## in a source file.
-## It is used by selecting the lines to sort, and then selecting one the
-## menus in Edit/Sort Ascending or Edit/Sort Descending
+"""Provides sort functions in the editors
 
+This file provides two sort functions, which can be used to sort lines
+in a source file.
+To use: first select the lines that you wish to sort, and then select
+one of the two menus:
+  - /Edit/Selection/Sort
+  - /Edit/Selection/Sort Reverse
+"""
+
+
+############################################################################
+## No user customization below this line
+############################################################################
+
+menu_name1 = "/Edit/Selection/Sort Reverse"
+menu_name2 = "/Edit/Selection/Sort"
 
 import GPS
 import string
 
-GPS.parse_xml ("""
+def on_gps_started (hook_name):
+  GPS.parse_xml ("""
+  <action name="sort selected lines descending" output="none" category="Editor">
+     <filter id="Source editor" />
+     <description>Sorts current selection</description>
+     <shell lang="python" >sort_selection.sort_selection(1)</shell>
+  </action>
+  <menu action="sort selected lines descending" after="Refill">
+     <title>""" + menu_name1 + """</title>
+  </menu>
   <action name="sort selected lines ascending" output="none" category="Editor">
      <filter id="Source editor" />
      <description>Sorts current selection</description>
      <shell lang="python" >sort_selection.sort_selection(0)</shell>
   </action>
-
   <menu action="sort selected lines ascending" after="Refill">
-     <title>/Edit/Sort Ascending</title>
-  </menu>
-
-   <action name="sort selected lines descending" output="none" category="Editor">
-      <filter id="Source editor" />
-      <description>Sorts current selection</description>
-      <shell lang="python" >sort_selection.sort_selection(1)</shell>
-   </action>
-
-  <menu action="sort selected lines descending" after="Refill">
-     <title>/Edit/Sort Descending</title>
+     <title>""" + menu_name2 + """</title>
   </menu>
 """)
 
@@ -49,7 +57,7 @@ def sort_selection (revert):
 
    if selection == "" or context.__class__ == GPS.EntityContext:
       return;
-      
+
    lines = string.split (selection,"\n");
    # strip off extraneous trailing "" line
    lines = lines[:-1];
@@ -60,3 +68,5 @@ def sort_selection (revert):
    ed.delete (start, to)
    ed.insert (start, "\n".join (lines) + "\n")
    ed.finish_undo_group()
+
+GPS.Hook ("gps_started").add (on_gps_started)
